@@ -12,7 +12,26 @@ class RDBService:
         self.database = database
 
     def __connect(self):
-        raise (NameError, "Unsupported!")
+        if self.database.type == 'mssql':
+            self.conn = pymssql.connect(server = self.database.host,
+                                        port = self.database.port,
+                                        user = self.database.account,
+                                        database = self.database.database,
+                                        password = self.database.password)
+        elif self.database.type == 'mysql':
+            self.conn = pymssql.connect(server = self.database.host,
+                                        port = self.database.port,
+                                        user = self.database.account,
+                                        database = self.database.database,
+                                        password = self.database.password)
+        elif self.database.type == 'postgresql':
+            self.conn = psycopg2.connect(host = self.database.host,
+                                        port = self.database.port,
+                                        user = self.database.account,
+                                        database = self.database.database,
+                                        password = self.database.password)
+        else:
+            raise (NameError, "Unsupported!")
 
     def close(self):
         if self.conn != None:
@@ -135,13 +154,6 @@ class MssqlService(RDBService):
     def __init__(self,database):
         super().__init__(database)
 
-    def __connect(self):
-        if self.conn is None:
-            self.conn = pymssql.connect(server = self.database.host,
-                                        port = self.database.port,
-                                        user = self.database.account,
-                                        database = self.database.database,
-                                        password = self.database.password)
 
     def __close(self):
         super().close()
@@ -203,13 +215,6 @@ class MysqlService(RDBService):
     def __init__(self,settings):
         super().__init__(settings)
 
-    def __connect(self):
-        if self.conn is None:
-            self.conn = pymssql.connect(server = self.database.host,
-                                        port = self.database.port,
-                                        user = self.database.account,
-                                        database = self.database.database,
-                                        password = self.database.password)
 
     # 根据${query}查找一条记录
     """
@@ -237,15 +242,6 @@ class MysqlService(RDBService):
 class PostgresqlService(RDBService):
     def __init__(self,settings):
         super().__init__(settings)
-
-    def __connect(self):
-        if self.conn is None:
-            self.conn = psycopg2.connect(host = self.database.host,
-                                        port = self.database.port,
-                                        user = self.database.account,
-                                        database = self.database.database,
-                                        password = self.database.password)
-
     #根据${query}查找多条记录
     """
     query = "where a=b or (c like 'd')" sql子句
